@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 import re
+import requests
 
-from uritemplate import expand
 from jsonschema import validate, SchemaError, ValidationError
 
 from pluct.request import Request
@@ -14,8 +14,8 @@ def add_methods(resource, s, auth=None):
         method = link.get("method", "GET")
         href = link.get("href")
         rel = link.get("rel")
-        href = expand(href, resource.data)
-        method_class = Request(method, href, auth)
+        # href = expand(href, resource.data)
+        method_class = Request(method, href, auth, resource)
         setattr(resource, rel, method_class.process)
 
 
@@ -79,7 +79,14 @@ class Resource(object):
 
 
 def get(url, auth=None):
-    response = Request('GET', url, auth).process()
+    headers = {
+        'content-type': 'application/json'
+    }
+    if auth:
+        headers['Authorization'] = '{0} {1}'.format(
+            auth['type'], auth['credentials']
+        )
+    response = requests.get(url, headers=headers)
     s = schema_from_header(response.headers, auth)
     return Resource(
         url=url,
